;; Copyright (C) 1995

;; Author: Anders Stenman <stenman@isy.liu.se>
;;         Automatic Control, Linkoping University. Sweden
;;
;; Keywords: AucTeX, toolbar

;; This file is NOT part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;; Installation:
;; =============
;;
;; 1. Put the XPM icons where you want them.
;; 2. Set the variable TeX-icon-directory to the directory
;;    that holds the icons.
;; 3. Load this file.

;; ------------------------------------------------------

;; Customize some variables that are CCCma specific
(custom-set-variables
;; expansion commands
 '(TeX-expand-list 
   '(("%p" TeX-printer-query) 
     ("%q" (lambda nil (TeX-printer-query TeX-queue-command 2))) 
     ("%v" TeX-style-check (("^a5$" "xdvi %d -paper a5") 
			    ("^landscape$" "xdvi %d -paper a4r -s 4") 
			    ("." "xdvi %d"))) 
     ("%l" TeX-style-check (("." "latex"))) 
     ("%s" file nil t) 
     ("%t" file t t) 
     ("%n" TeX-current-line) 
     ("%d" file "dvi" t) 
     ("%f" file "ps" t) 
     ("%a" file "pdf" t) 
     ("%u" (lambda nil 
	     (concat "file:" (TeX-master-directory) 
		     (TeX-master-file) "/" 
		     (TeX-master-file nil nil) ".html")))))
;; list of commands
 '(TeX-command-list 
   '(("TeX" "tex '\\nonstopmode\\input %t'" TeX-run-TeX nil t) 
     ("TeX Interactive" "tex %t" TeX-run-interactive nil t) 
     ("LaTeX" "%l '\\nonstopmode\\input{%t}'" TeX-run-LaTeX nil t) 
     ("LaTeX Interactive" "%l %t" TeX-run-interactive nil t) 
     ("LaTeX2e" "latex2e '\\nonstopmode\\input{%t}'" TeX-run-LaTeX nil t) 
     ("View" "%v " TeX-run-silent nil nil) 
     ("Print" "%p " TeX-run-command nil nil) 
     ("Queue" "%q" TeX-run-background nil nil) 
     ("File" "dvips %d -o %f ; gv -watch %f" TeX-run-silent nil nil) 
     ("LaTeX2HTML" "latex2html %t" TeX-run-command nil nil)
     ("Browse HTML" "netscape %u" TeX-run-command nil nil)
     ("BibTeX" "bibtex %s" TeX-run-BibTeX nil nil) 
     ("Index" "makeindex %s" TeX-run-command nil t) 
     ("Check" "lacheck %s" TeX-run-compile nil t) 
     ("Spell" "<ignored>" TeX-run-ispell nil nil) 
     ("Other" "" TeX-run-command t t) 
     ("Makeinfo" "makeinfo %t" TeX-run-compile nil t) 
     ("AmSTeX" "amstex '\\nonstopmode\\input %t'" TeX-run-TeX nil t)))
;; list of printers
 '(TeX-printer-list 
   '(("lp" "dvips -f %s | lpr -Plp" "lpq -Plp") 
     ("lpduplex" "dvips -f %s | lpr -Plpduplex" "lpq -Plpduplex") 
     ("lpc_paper" "dvips -f %s | lpr -Plpc_paper" "lpq -Plpc") 
     ("lpc_trans" "dvips -f %s | lpr -Plpc_trans" "lpq -Plpc_trans") 
     ("PS file" "dvips %s -o %f" nil)
     ("PDF file" "dvips -f %s | ps2pdf - %a" nil)))
;; Default printer
 '(TeX-printer-default "lp")
)

;; Define icons

(defvar TeX-icon-directory "/usr/local/xemacs/site-packages/lisp/tex-toolbar"
  "The directory where the icon data files for AucTeX are
installed.")

(defvar TeX-LaTeX-icon 
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "tex.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "tex.xbm" TeX-icon-directory))
	 )
   )
  "A LaTeX toolbar icon.")

(defvar TeX-BibTeX-icon 
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "bibtex.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "bibtex.xbm" TeX-icon-directory))
	 )
   )
  "A BibTeX toolbar icon.")

(defvar TeX-view-icon 
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "dvi.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "dvi.xbm" TeX-icon-directory))
	 )
   )
  "A Preview toolbar icon.")

(defvar TeX-print-icon
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "print.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "print.xbm" TeX-icon-directory))
	 )
   )
  "A Print toolbar icon.")

(defvar TeX-ghostview-icon 
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "ps.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "ps.xbm" TeX-icon-directory))
	 )
   )
  "A Ghostview toolbar icon.")

(defvar TeX-html-icon 
  (toolbar-make-button-list 
   (cond ((featurep 'xpm)
	  (expand-file-name "html.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "html.xbm" TeX-icon-directory))
	 )
   )
  "A LaTeX2HTML toolbar icon.")

(defvar TeX-help-icon
  (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "help.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "help.xbm" TeX-icon-directory))
	 )
   )
  "A Help toolbar icon.")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defvar TeX-niques1
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "splitv.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "splitv.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 1.")

(defvar TeX-niques2
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "splith.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "splith.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 2.")

(defvar TeX-niques3
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "keepthis.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "keepthis.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 3.")

(defvar TeX-niques4
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "keepother.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "keepother.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 4.")

(defvar TeX-niques5
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "killbuff.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "killbuff.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 5.")

(defvar TeX-niques6
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "comment.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "comment.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 6.")

(defvar TeX-niques7
 (toolbar-make-button-list
   (cond ((featurep 'xpm)
	  (expand-file-name "uncomment.xpm" TeX-icon-directory))
	 ((featurep 'x)
	  (expand-file-name "uncomment.xbm" TeX-icon-directory))
	 )
   )
  "Extra toolbar icon - 7.")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;





;; Define new commands

(defun TeX-toolbar-html ()
  (interactive)
  "Run the LaTeX2HTML command from the toolbar. Popups a 
confirmation dialog box."
;  (let* ((html-dir (file-name-sans-extension (buffer-name)))
  (let* ((html-root (concat (TeX-master-directory) 
			    (TeX-master-file) 
			    "/" 
			    (TeX-master-file nil nil) ".html"))
	 (dialog-entry 
	  (append (list (concat "Running `latex2html' may take some time.
The root HTML document will be in\n" html-root "\n\n")
			["Create HTML" (TeX-command-menu "LaTeX2HTML") t]
			["Browse HTML" (TeX-command-menu "Browse HTML") t]
			nil ["Cancel" ignore t]))))
	  (popup-dialog-box dialog-entry)))

(defun TeX-toolbar-print ()
  (interactive)
  "Run the Print command from the toolbar. Popups a printer
selection dialog box."
  (let* ((printer-list (mapcar (function car) TeX-printer-list))
	 (dialog-entry
	  (append (list "Select printer!")
		  (mapcar
		   (function
		    (lambda (pr)
		      (vector pr (list 'TeX-toolbar-print1 pr) t)))
		   printer-list)
		  (list nil
			["Cancel" ignore t]))))
    (popup-dialog-box dialog-entry)))

(defun TeX-toolbar-print1 (printer)
  (let* ((printer-entry (assoc printer TeX-printer-list)))
    (TeX-command-menu-print printer (nth 1 printer-entry) "Print")))

(defun TeX-toolbar-help ()
  "Browse the AucTeX info file from the toolbar in a separate frame."
  (interactive)
  (if (or (not toolbar-info-frame)
	  (not (frame-live-p toolbar-info-frame)))
      (progn
	(setq toolbar-info-frame (make-frame))
	(select-frame toolbar-info-frame)
	(raise-frame toolbar-info-frame)))
  (if (frame-iconified-p toolbar-info-frame)
      (deiconify-frame toolbar-info-frame))
  (select-frame toolbar-info-frame)
  (raise-frame toolbar-info-frame)
  (info "auctex"))

;; Finally, define the toolbar.

(defvar TeX-toolbar
  '(
; standard XEmacs icons
    [toolbar-file-icon	  toolbar-open	  t	"Open a file"	]
   ; [toolbar-folder-icon  toolbar-dired	  t	"View directory"]

    [toolbar-disk-icon	  toolbar-save	  t	"Save buffer"	]
  [:style 2d :size 30]
    [toolbar-cut-icon	  toolbar-cut	  t	"Kill region"]
    [toolbar-copy-icon	  toolbar-copy	  t	"Copy region"]
    [toolbar-paste-icon	  toolbar-paste	  t 	"Paste from clipboard"]
  [:style 2d :size 30]
    [toolbar-undo-icon	  toolbar-undo	  t	"Undo edit"	]
  [:style 2d :size 30]
    [toolbar-spell-icon	  toolbar-ispell  t	"Spellcheck"	]
    [toolbar-replace-icon toolbar-replace t	"Replace text"	]
  [:style 2d :size 10]
     [TeX-niques1   split-window-vertically t "Split vertically"]
     [TeX-niques2   split-window-horizontally t "Split horizontally"]
     [TeX-niques3   delete-other-windows t "Unsplit (keep this)"]
     [TeX-niques4   delete-window  t "Unsplit (keep others)"]
     [TeX-niques5   kill-this-buffer t "Kill buffer"]
  [:style 2d :size 10]
     [TeX-niques6   TeX-comment-region t "Comment region"]
     [TeX-niques7   TeX-un-comment-region t "Uncomment region"]
  [:style 2d :size 10]
; (La)TeX specific icons
    [TeX-LaTeX-icon	(if (string= mode-name "LaTeX")
			    (TeX-command-menu "LaTeX Interactive")
			  (TeX-command-menu "TeX Interactive")) t "Run (La)TeX on document"]
 ;   [TeX-BibTeX-icon    (TeX-command-menu "BibTeX") t "Run BibTeX on document"]
    [TeX-view-icon      (TeX-command-menu "View") t "Preview document"]
    [TeX-ghostview-icon (TeX-command-menu "File") t "Create PS document"]
 ;   [TeX-html-icon       TeX-toolbar-html t "Create HTML document"]
 ;   [TeX-print-icon      TeX-toolbar-print t "Print document"]
    nil
    [toolbar-mail-icon	  toolbar-mail	  t	"Mail"		]
    [:style 2d :size 10]
    [TeX-help-icon       TeX-toolbar-help t "AucTeX help"])
  "The toolbar used in AucTeX.")

(defun TeX-install-toolbar ()
  (set-specifier top-toolbar (cons (current-buffer) TeX-toolbar)))

(add-hook 'LaTeX-mode-hook 'TeX-install-toolbar)
(add-hook 'TeX-mode-hook 'TeX-install-toolbar)

(provide 'tex-toolbar)
